@@ -116,7 +116,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright 2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -128,8 +128,6 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -137,11 +135,11 @@ import aws_cdk.aws_cloudwatch
 import aws_cdk.aws_iam
 import aws_cdk.aws_kinesis
 import aws_cdk.aws_logs
-import aws_cdk.core
+import constructs
 
 
 class ApiGatewayToKinesisStreams(
-    aws_cdk.core.Construct,
+    constructs.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-apigateway-kinesisstreams.ApiGatewayToKinesisStreams",
 ):
@@ -151,17 +149,17 @@ class ApiGatewayToKinesisStreams(
 
     def __init__(
         self,
-        scope: aws_cdk.core.Construct,
+        scope: constructs.Construct,
         id: builtins.str,
         *,
-        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-        put_record_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
+        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        put_record_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
         put_record_request_template: typing.Optional[builtins.str] = None,
-        put_records_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
+        put_records_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
         put_records_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -181,25 +179,6 @@ class ApiGatewayToKinesisStreams(
         :since: 1.62.0
         :summary: Constructs a new instance of the ApiGatewayToKinesisStreams class.
         '''
-        if __debug__:
-            def stub(
-                scope: aws_cdk.core.Construct,
-                id: builtins.str,
-                *,
-                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                put_record_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
-                put_record_request_template: typing.Optional[builtins.str] = None,
-                put_records_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
-                put_records_request_template: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
-            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToKinesisStreamsProps(
             api_gateway_props=api_gateway_props,
             create_cloud_watch_alarms=create_cloud_watch_alarms,
@@ -214,32 +193,32 @@ class ApiGatewayToKinesisStreams(
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGateway")
     def api_gateway(self) -> aws_cdk.aws_apigateway.RestApi:
         return typing.cast(aws_cdk.aws_apigateway.RestApi, jsii.get(self, "apiGateway"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGatewayLogGroup")
     def api_gateway_log_group(self) -> aws_cdk.aws_logs.LogGroup:
         return typing.cast(aws_cdk.aws_logs.LogGroup, jsii.get(self, "apiGatewayLogGroup"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGatewayRole")
     def api_gateway_role(self) -> aws_cdk.aws_iam.Role:
         return typing.cast(aws_cdk.aws_iam.Role, jsii.get(self, "apiGatewayRole"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="kinesisStream")
     def kinesis_stream(self) -> aws_cdk.aws_kinesis.Stream:
         return typing.cast(aws_cdk.aws_kinesis.Stream, jsii.get(self, "kinesisStream"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="apiGatewayCloudWatchRole")
     def api_gateway_cloud_watch_role(self) -> typing.Optional[aws_cdk.aws_iam.Role]:
         return typing.cast(typing.Optional[aws_cdk.aws_iam.Role], jsii.get(self, "apiGatewayCloudWatchRole"))
 
-    @builtins.property
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cloudwatchAlarms")
     def cloudwatch_alarms(
         self,
@@ -266,14 +245,14 @@ class ApiGatewayToKinesisStreamsProps:
     def __init__(
         self,
         *,
-        api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+        api_gateway_props: typing.Optional[aws_cdk.aws_apigateway.RestApiProps] = None,
         create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
         existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-        kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-        put_record_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
+        kinesis_stream_props: typing.Optional[aws_cdk.aws_kinesis.StreamProps] = None,
+        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        put_record_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
         put_record_request_template: typing.Optional[builtins.str] = None,
-        put_records_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
+        put_records_request_model: typing.Optional[aws_cdk.aws_apigateway.ModelOptions] = None,
         put_records_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -299,30 +278,6 @@ class ApiGatewayToKinesisStreamsProps:
             put_record_request_model = aws_cdk.aws_apigateway.ModelOptions(**put_record_request_model)
         if isinstance(put_records_request_model, dict):
             put_records_request_model = aws_cdk.aws_apigateway.ModelOptions(**put_records_request_model)
-        if __debug__:
-            def stub(
-                *,
-                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
-                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
-                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
-                kinesis_stream_props: typing.Optional[typing.Union[aws_cdk.aws_kinesis.StreamProps, typing.Dict[str, typing.Any]]] = None,
-                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
-                put_record_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
-                put_record_request_template: typing.Optional[builtins.str] = None,
-                put_records_request_model: typing.Optional[typing.Union[aws_cdk.aws_apigateway.ModelOptions, typing.Dict[str, typing.Any]]] = None,
-                put_records_request_template: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
-            check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
-            check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
-            check_type(argname="argument existing_stream_obj", value=existing_stream_obj, expected_type=type_hints["existing_stream_obj"])
-            check_type(argname="argument kinesis_stream_props", value=kinesis_stream_props, expected_type=type_hints["kinesis_stream_props"])
-            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
-            check_type(argname="argument put_record_request_model", value=put_record_request_model, expected_type=type_hints["put_record_request_model"])
-            check_type(argname="argument put_record_request_template", value=put_record_request_template, expected_type=type_hints["put_record_request_template"])
-            check_type(argname="argument put_records_request_model", value=put_records_request_model, expected_type=type_hints["put_records_request_model"])
-            check_type(argname="argument put_records_request_template", value=put_records_request_template, expected_type=type_hints["put_records_request_template"])
         self._values: typing.Dict[str, typing.Any] = {}
         if api_gateway_props is not None:
             self._values["api_gateway_props"] = api_gateway_props
